@@ -2,21 +2,16 @@
 # -*- coding: utf-8 -*-
 
 import os
-import logging
 from .arg_parse import arg_parse
+from .logger import setup_logger
 
 home_dir = os.path.expanduser("~")
 config_file = home_dir + "/.config/robin/software_deployment.yaml"
 
-
 log_filename = 'upload.log'
-log_level = logging.INFO
-log_format = '%(asctime)s %(levelname)s %(message)s'
-
-logging.basicConfig(filename=log_filename, level=log_level, format=log_format)
-logger = logging.getLogger()
 
 def main():
+    setup_logger(log_filename)
     arg_parse(config_file)
 
 if __name__ == "__main__":
